@@ -21,9 +21,6 @@
 import time
 import traceback
 
-import twitter as twitter_api
-import bitlyapi
-
 import fedmsg
 import fedmsg.meta
 from fedmsg.commands import BaseCommand
